// Control window for BFG, written by Zenja Solaja, July 2000

#include "ZBFGApplication.h"

//=================
ZViewControl::ZViewControl(BRect rect, char *name)
	:BView(rect, name, B_FOLLOW_ALL, B_WILL_DRAW)
{
	rgb_color Orange = {255, 224, 192, 255};
	SetViewColor(Orange);
}  

//==========================
ZWindowControl::ZWindowControl(BRect frame)
	: BWindow(frame, "Search Options", B_TITLED_WINDOW, B_NOT_RESIZABLE | B_NOT_ZOOMABLE)
{
	BRect aRect;
	
	// Menu - Directory History
	//This must be highest in view hierachy since, 
	//since BControlView has no menus!!!!
	aRect.Set(295, 55, 300, 75);
	PrepareDirHistoryMenu(aRect);
	AddChild(fDirHistory);
	
	//Associate view with window
	frame.OffsetTo(B_ORIGIN);
    fZViewControl = new ZViewControl(frame, "ZS-ViewControl");
    AddChild(fZViewControl);
        
	// Text Control - Search string
	aRect.Set(20, 20, 220, 50);
	fTextSearchString = new BTextControl(aRect, "Search Text", "Enter Search String:", "", new BMessage(TEXT_SEARCH_STRING_MSG));
	fTextSearchString->SetText("test");
	fZViewControl->AddChild(fTextSearchString);
	
	// Text Control - Directory name
	aRect.Set(20, 55, 220, 85);
	fSelectDirText = new BTextControl(aRect, "Directory Text", "", "", 0);
	fSelectDirText->SetDivider(0);
	fSelectDirText->SetText(selected_path.Path()); //Initial value
	fZViewControl->AddChild(fSelectDirText);
	
	// Button Control - Select directory
	aRect.Set(235, 50, 290, 80);
	fSelectDirButton = new BButton(aRect, "Directory Button", "Directory", new BMessage(SELECT_DIR_MSG));
	fZViewControl->AddChild(fSelectDirButton);
	
	// Checkbox - Search subdirectories
	aRect.Set(20, 90, 150, 110);
	fSubDirectoryCheckBox = new BCheckBox(aRect, "Subdirectory CheckBox", "Search subdirectories", new BMessage(SUBDIRECTORY_CHKBOX_MSG));
	fSubDirectoryCheckBox->SetValue(zbfg_subdirectory_flag);
	fZViewControl->AddChild(fSubDirectoryCheckBox);
	// Checkbox - Ignore Case
	aRect.Set(20, 110, 100, 130);
	fIgnoreCaseCheckBox = new BCheckBox(aRect, "Subdirectory CheckBox", "Ignore Case", new BMessage(IGNORE_CASE_CHKBOX_MSG));
	fIgnoreCaseCheckBox->SetValue(zbfg_ignore_case_flag);
	fZViewControl->AddChild(fIgnoreCaseCheckBox);
	
	// Button control - Begin search
	aRect.Set(230, 120, 290, 160);
	fButtonBegin = new BButton(aRect, "Begin Button", "Begin", new BMessage(BUTTON_BEGIN_SEARCH_MSG));
	fZViewControl->AddChild(fButtonBegin);
	
	//Set initial settings
	UpdateDirHistory(selected_path.Path());
}

void ZWindowControl::MessageReceived(BMessage* message)
{
	BAlert *alert;
					
	switch (message->what) {
		case TEXT_SEARCH_STRING_MSG:
			strcpy(search_string,fTextSearchString->Text());
			break;
		
		case BUTTON_BEGIN_SEARCH_MSG:
			if (!search_in_progress_flag)
			{
				strcpy(search_string,fTextSearchString->Text());
				if (strlen(search_string) < 2) {
					alert = new BAlert("Error", "Invalid search string", "OK");
					alert->Go();
					break;
				}
			
				UpdateDirHistory(fSelectDirText->Text());
				fButtonBegin->SetLabel("Cancel");
				Start_BFG(fSelectDirText->Text());
				break;
			}
			PostMessage(SEARCH_FINISHED_MSG);
			break;
			
		case SEARCH_FINISHED_MSG:
			search_in_progress_flag = false;
			fButtonBegin->SetLabel("Begin");
			break;
						
		case SELECT_DIR_MSG: 
			glob_filepanel->Show();
			break;
				
		case DIRECTORY_CHOSEN_MSG:
			fSelectDirText->SetText(selected_path.Path());
			break;
			
		case SUBDIRECTORY_CHKBOX_MSG:
			zbfg_subdirectory_flag = fSubDirectoryCheckBox->Value();
			break;
		
		case IGNORE_CASE_CHKBOX_MSG:
			zbfg_ignore_case_flag = fIgnoreCaseCheckBox->Value();
			break;
			
		/*
		case OPEN_FILE_MSG: {
			filepanel->ImageSelected();
			filepanel->Hide();
			zv_window->PrepareBitmap(list_navigation->position->contents);
			break;
		}
		*/
		case DIR_HISTORY_IDX + 0:
		case DIR_HISTORY_IDX + 1:
		case DIR_HISTORY_IDX + 2:
		case DIR_HISTORY_IDX + 3:
		case DIR_HISTORY_IDX + 4:
		case DIR_HISTORY_IDX + 5:
		case DIR_HISTORY_IDX + 6:
			ProcessHistoryRequest(message);
			break;
			
		default:
			BWindow::MessageReceived(message);
	}
}

bool ZWindowControl::QuitRequested()
{
    be_app->PostMessage(B_QUIT_REQUESTED);
    return(true);
}

void ZWindowControl::PrepareDirHistoryMenu(BRect menuRect)
{
	fDirHistory = new BMenuBar(menuRect, "DirHistory");
	fDirHistoryMenu = new BMenu("V");
	BMenuItem *item;
	int i;
	for (i=0; i<MAX_NUM_DIR_HISTORY; i++)
		fDirHistoryMenu->AddItem(item = new BMenuItem("", new BMessage(DIR_HISTORY_IDX + i),0,0));
	fDirHistory->AddItem(fDirHistoryMenu);	
}

void ZWindowControl::ProcessHistoryRequest(BMessage *message)
{
	BMenuItem *aItem;
	int selection = (message->what - DIR_HISTORY_IDX);
	if (selection < 0 || selection >= MAX_NUM_DIR_HISTORY)
	{
		BAlert *alert = new BAlert("Warning", "Invalid history selection", "OK");
		alert->Go();
		return;
	}
	aItem = fDirHistoryMenu->ItemAt(selection);
	fSelectDirText->SetText(aItem->Label());
	return;
}

void ZWindowControl::UpdateDirHistory(const char *newlabel)
{
	BMenuItem *aItem;
	int i;
	int count = fDirHistoryMenu->CountItems();
	if ( count < 0 || count> MAX_NUM_DIR_HISTORY)
	{
		BAlert *alert = new BAlert("Warning", "Cannot update dir history", "OK");
		alert->Go();
		return;
	}
	
	//check if newlabel already in history.  If so, do not update history
	for (i = 0; i < count; i++)
		if (strcmp(newlabel, fDirHistoryMenu->ItemAt(i)->Label()) == 0)
			return;
	
	for (i = count-1; i >= 0; i--)
	{
		aItem = fDirHistoryMenu->ItemAt(i+1);
		if (aItem != NULL)
			aItem->SetLabel(fDirHistoryMenu->ItemAt(i)->Label());
	}
	fDirHistoryMenu->ItemAt(0)->SetLabel(newlabel);		
}



